@@ -7,13 +7,13 @@
 *********************************************************************/
 
 
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
+#include <cstdio>
 
 #include "general.h"
 #include "error.h"
 
+using namespace std ;
+
 void merror(const char* Msg1, const char* Msg2)
 {
 #if defined(R_PORT)
